lenstronomy.SimulationAPI.ObservationConfig package — lenstronomy 1.8.2 documentation

# lenstronomy.SimulationAPI.ObservationConfig package

## Submodules

## lenstronomy.SimulationAPI.ObservationConfig.DES module

Provisional DES instrument and observational settings. See Optics and Observation Conditions spreadsheet at https://docs.google.com/spreadsheets/d/1pMUB_OOZWwXON2dd5oP8PekhCT5MBBZJO1HV7IMZg4Y/edit?usp=sharing for list of sources.

class `lenstronomy.SimulationAPI.ObservationConfig.DES.` `DES`(band='g', psf_type='GAUSSIAN', coadd_years=3)

  Bases: `object`

  class contains DES instrument and observation configurations

  `camera` = None

    Parameters: | read_noise – std of noise generated by read-out (in units of electrons) pixel_scale – scale (in arcseconds) of pixels ccd_gain – electrons/ADU (analog-to-digital unit).

  `kwargs_single_band`()

    Returns: | merged kwargs from camera and obs dicts

## lenstronomy.SimulationAPI.ObservationConfig.Euclid module

Provisional Euclid instrument and observational settings. See Optics and Observation Conditions spreadsheet at https://docs.google.com/spreadsheets/d/1pMUB_OOZWwXON2dd5oP8PekhCT5MBBZJO1HV7IMZg4Y/edit?usp=sharing for list of sources.

class `lenstronomy.SimulationAPI.ObservationConfig.Euclid.` `Euclid`(band='VIS', psf_type='GAUSSIAN', coadd_years=6)

  Bases: `object`

  class contains Euclid instrument and observation configurations

  `camera` = None

    Parameters: | read_noise – std of noise generated by read-out (in units of electrons) pixel_scale – scale (in arcseconds) of pixels ccd_gain – electrons/ADU (analog-to-digital unit).

  `kwargs_single_band`()

    Returns: | merged kwargs from camera and obs dicts

## lenstronomy.SimulationAPI.ObservationConfig.HST module

Provisional HST instrument and observational settings. See Optics and Observation Conditions spreadsheet at https://docs.google.com/spreadsheets/d/1pMUB_OOZWwXON2dd5oP8PekhCT5MBBZJO1HV7IMZg4Y/edit?usp=sharing for list of sources.

class `lenstronomy.SimulationAPI.ObservationConfig.HST.` `HST`(band='TDLMC_F160W', psf_type='PIXEL', coadd_years=None)

  Bases: `object`

  class contains HST instrument and observation configurations

  `camera` = None

    Parameters: | read_noise – std of noise generated by read-out (in units of electrons) pixel_scale – scale (in arcseconds) of pixels ccd_gain – electrons/ADU (analog-to-digital unit).

  `kwargs_single_band`()

    Returns: | merged kwargs from camera and obs dicts

## lenstronomy.SimulationAPI.ObservationConfig.LSST module

Provisional LSST instrument and observational settings. See Optics and Observation Conditions spreadsheet at https://docs.google.com/spreadsheets/d/1pMUB_OOZWwXON2dd5oP8PekhCT5MBBZJO1HV7IMZg4Y/edit?usp=sharing for list of sources.

class `lenstronomy.SimulationAPI.ObservationConfig.LSST.` `LSST`(band='g', psf_type='GAUSSIAN', coadd_years=10)

  Bases: `object`

  class contains LSST instrument and observation configurations

  `camera` = None

    Parameters: | read_noise – std of noise generated by read-out (in units of electrons) pixel_scale – scale (in arcseconds) of pixels ccd_gain – electrons/ADU (analog-to-digital unit).

  `kwargs_single_band`()

    Returns: | merged kwargs from camera and obs dicts

## Module contents